==> pyukiwiki-0.2.0-beta2-update-full.tar.gz: pyukiwiki-0.2.0-beta2-update-full/lib/google_analytics.inc.pl <==
######################################################################
# google_analytics.inc.pl - This is PyukiWiki, yet another Wiki clone.
# $Id: google_analytics.inc.pl,v 1.111 2011/12/21 05:00:57 papu Exp $
#
# "PyukiWiki" version 0.2.0-beta2 $$
# Author: Nanami http://nanakochi.daiba.cx/
# Copyright (C) 2004-2011 by Nekyo.
# http://nekyo.qp.land.to/
# Copyright (C) 2005-2011 PyukiWiki Developers Team
# http://pyukiwiki.sfjp.jp/
# Based on YukiWiki http://www.hyuki.com/yukiwiki/
# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
# License: GPL2 and/or Artistic or each later version
#
# This program is free software; you can redistribute it and/or
# modify it under the same terms as Perl itself.
# Return:LF Code=EUC-JP 1TAB=4Spaces
######################################################################
# This is extented plugin.
# To use this plugin, rename to 'google_analytics.inc.cgi'
######################################################################
#
# google-analytics.com ӥˤ롢ȥȥå󥰥ƥ
#
# http://google-analytics.com/
#
# Ȥ
#   google_analytics.inc.plgoogle_analytics.inc.cgi˥͡
#   info/setup.cgi Ͽ (UA- ǻϤޤ) 
#     $GOOGLEANALTYCS::ACCOUNT ѿ˥åȤ롣
#    ʣΥ֥ɥᥤ󤬤ϡ
#     $GOOGLEANALTYCS::MULTISUB  .example.comפηǵܤ롣
#   ʣΥȥåץ٥ɥᥤ󤬤硢
#     $GOOGLEANALTYCS::MULTITOP=1 򥻥åȤ롣
#
# ա
#   פǣ500ӥ塼ĶȲݶ⤬ȯޤ
#
######################################################################
# UA- ǻϤޤ륢Ȥꤹ롣
$GOOGLEANALTYCS::ACCOUNT=""
	if($GOOGLEANALTYCS::ACCOUNT eq '');
#
# ʣΥ֥ɥᥤ󤬤 ĤΥɥᥤ󤬤礽Υɥᥤꤹ롣
# example : [.example.com]
$GOOGLEANALTYCS::MULTISUB=""
	if($GOOGLEANALTYCS::MULTISUB eq "");
#
# ʣΥȥåץ٥ɥᥤ󤬤磱
$GOOGLEANALTYCS::MULTITOP=0
	if($GOOGLEANALTYCS::MULTITOP ne 0);
######################################################################
sub plugin_google_analytics_init {
	if($::form{cmd} eq "" || $::form{cmd} eq "read") {
		if($GOOGLEANALTYCS::ACCOUNT ne '') {
			my $header=<<EOM;
<script type="text/javascript"><!--
  var _gaq = _gaq || [];
  _gaq.push(['_setAccount', '$GOOGLEANALTYCS::ACCOUNT']);@{[$GOOGLEANALTYCS::MULTISUB ne '' ? "  _gaq.push(['_setDomainName', '$GOOGLEANALTYCS::MULTISUB']);\n" : ""]}@{[$GOOGLEANALTYCS::MULTITOP ne 0 ? "  _gaq.push(['_setDomainName', 'none']);\n  _gaq.push(['_setAllowLinker', true]);\n" : ""]}
  _gaq.push(['_trackPageview']);
  (function() {
    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
  })();
//--></script>
EOM
			return ('init'=>1, 'header'=>$header);
		}
	}
	return ('init'=>0);
}
1;
__DATA__
sub plugin_google_analytics_setup {
	return(
	'ja'=>'ȥȥå󥰥ƥ for google-analytics.com',
	'en'=>'Site Tracking System for google-analytics.com',
	'url'=>'http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/ExPlugin/google_analytics/'
	);
}
__END__

==> pyukiwiki-0.2.1-beta2-update-full.tar.gz: pyukiwiki-0.2.1-beta2-update-full/lib/google_analytics.inc.pl <==
######################################################################
# google_analytics.inc.pl - This is PyukiWiki, yet another Wiki clone.
# $Id: google_analytics.inc.pl,v 1.416 2012/09/11 00:42:59 papu Exp $
# Build on 2012-09-11 08:19:37
#
# "PyukiWiki" ver 0.2.1-beta2 $$
# Author: Nanami http://nanakochi.daiba.cx/
# Copyright (C) 2004-2007 Nekyo
# Copyright (C) 2005-2012 PyukiWiki Developers Team
# http://pyukiwiki.info/
# Based on YukiWiki http://www.hyuki.com/yukiwiki/
# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
# License: GPL3 and/or Artistic or each later version
#
# This program is free software; you can redistribute it and/or
# modify it under the same terms as Perl itself.
# Return:CRLF Code=EUC-JP 1TAB=4Spaces
######################################################################
# This is extented plugin.
# To use this plugin, rename to 'google_analytics.inc.cgi'
######################################################################
#
# google-analytics.com ӥˤ롢ȥȥå󥰥ƥ
#
# http://google-analytics.com/
#
# Ȥ
#   google_analytics.inc.plgoogle_analytics.inc.cgi˥͡
#   info/setup.cgi Ͽ (UA- ǻϤޤ) 
#     $GOOGLEANALTYCS::ACCOUNT ѿ˥åȤ롣
#    ʣΥ֥ɥᥤ󤬤ϡ
#     $GOOGLEANALTYCS::MULTISUB  .example.comפηǵܤ롣
#   ʣΥȥåץ٥ɥᥤ󤬤硢
#     $GOOGLEANALTYCS::MULTITOP=1 򥻥åȤ롣
#
# ա
#   פǣ500ӥ塼ĶȲݶ⤬ȯޤ
#
######################################################################
# UA- ǻϤޤ륢Ȥꤹ롣
$GOOGLEANALTYCS::ACCOUNT=""
	if($GOOGLEANALTYCS::ACCOUNT eq '');
#
# ʣΥ֥ɥᥤ󤬤 ĤΥɥᥤ󤬤礽Υɥᥤꤹ롣
# example : [.example.com]
$GOOGLEANALTYCS::MULTISUB=""
	if($GOOGLEANALTYCS::MULTISUB eq "");
#
# ʣΥȥåץ٥ɥᥤ󤬤磱
$GOOGLEANALTYCS::MULTITOP=0
	if($GOOGLEANALTYCS::MULTITOP ne 0);
######################################################################
# Initlize											# comment
sub plugin_google_analytics_init {
	if($::form{cmd} eq "" || $::form{cmd} eq "read") {
		if($GOOGLEANALTYCS::ACCOUNT ne '') {
			my $header=<<EOM;
<script type="text/javascript"><!--
  var _gaq = _gaq || [];
  _gaq.push(['_setAccount', '$GOOGLEANALTYCS::ACCOUNT']);@{[$GOOGLEANALTYCS::MULTISUB ne '' ? "  _gaq.push(['_setDomainName', '$GOOGLEANALTYCS::MULTISUB']);\n" : ""]}@{[$GOOGLEANALTYCS::MULTITOP ne 0 ? "  _gaq.push(['_setDomainName', 'none']);\n  _gaq.push(['_setAllowLinker', true]);\n" : ""]}
  _gaq.push(['_trackPageview']);
  (function() {
    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
  })();
//--></script>
EOM
			return ('init'=>1, 'header'=>$header);
		}
	}
	return ('init'=>0);
}
1;
__DATA__
sub plugin_google_analytics_setup {
	return(
	'ja'=>'ȥȥå󥰥ƥ for google-analytics.com',
	'en'=>'Site Tracking System for google-analytics.com',
	'url'=>'http://pyukiwiki.info/PyukiWiki/Plugin/ExPlugin/google_analytics/'
	);
}
__END__
